@@ -289,7 +289,8 @@ static void init_nullses(void)
     nullsession->antisubs = init_list();
     nullsession->binds = init_hash();
     nullsession->next = 0;
-    nullsession->sessionstart=nullsession->idle_since=time(0);
+    nullsession->sessionstart=nullsession->idle_since=
+        nullsession->server_idle_since=time(0);
     nullsession->debuglogfile=0;
     nullsession->debuglogname=0;
     for (i=0;i<HISTORY_SIZE;i++)
@@ -823,6 +824,7 @@ static void read_mud(struct session *ses)
         {
             *cpdest = '\0';
             do_one_line(linebuffer,1,ses);
+            ses->lastintitle=0;
 
             cpsource++;
             cpdest=linebuffer;
@@ -840,7 +842,10 @@ static void read_mud(struct session *ses)
             }
             *cpdest=0;
             if (cpdest!=linebuffer)
+            {
                 do_one_line(linebuffer,0,ses);
+                ses->lastintitle=0;
+            }
             cpdest=linebuffer;
         }
         else
@@ -850,6 +855,7 @@ static void read_mud(struct session *ses)
     {
         *cpdest=0;
         do_one_line(linebuffer,1,ses);
+        ses->lastintitle=0;
         cpdest=linebuffer;
     }
     *cpdest = '\0';
@@ -896,7 +902,7 @@ static void do_one_line(char *line,int nl,struct session *ses)
     };
     _=line;
     PROF("processing incoming colors");
-    do_in_MUD_colors(line,0);
+    do_in_MUD_colors(line,0,ses);
     isnb=isnotblank(line,0);
     PROF("promptactions");
     if (!ses->ignore && (nl||isnb))
