@@ -4,7 +4,9 @@
 #include "protos/utils.h"
 
 extern int colors[];
-const char *attribs[8]={"",";5",";3",";3;5",";4",";4;5",";4;3",";4;3;5"};
+const char *attribs[16]={"",";5",";3",";3;5",";4",";4;5",";4;3",";4;3;5",
+        ";9",";5;9",";3;9",";3;5;9",";4;9",";4;5;9",";4;3;9",";4;3;5;9",
+};
 #ifdef GRAY2
 const char *fcolors[16]={";30",  ";34",  ";32",  ";36",
                             ";31",  ";35",  ";33",  "",
