@@ -133,6 +133,9 @@ void substitute_myvars(char *arg,char *result,struct session *ses)
                     if (strcmp(varname,"IDLETIME")==0)
                         sprintf(value,"%ld", (long int)(time(0)-ses->idle_since));
                     else
+                    if (strcmp(varname,"SERVERIDLE")==0)
+                        sprintf(value,"%ld", (long int)(time(0)-ses->server_idle_since));
+                    else
                     if (_ && (strcmp(varname,"LINE")==0 ||
                         strcmp(varname,"_")==0))
                         strcpy(value,_);
